@@ -29,11 +29,11 @@ Perl::LanguageServer - Language Server and Debug Protocol Adapter for Perl
 
 =head1 VERSION
 
-Version 2.2.0
+Version 2.3.0
 
 =cut
 
-our $VERSION = '2.2.0';
+our $VERSION = '2.3.0';
 
 
 =head1 SYNOPSIS
@@ -51,10 +51,74 @@ with various editors/includes
 
 L<https://microsoft.github.io/debug-adapter-protocol/overview>
 
-To use both with Visual Studio Code, install the extention "perl"
+Should work with any Editor/IDE that support the Language-Server-Protocol.
+
+To use both with Visual Studio Code, install the extension "perl"
 
 Any comments and patches are welcome.
 
+=head2 Features
+
+=over 4
+
+=item * Language Server
+
+=over 4
+
+=item * Syntax checking
+
+=item * Symbols in file
+
+=item * Symbols in workspace/directory
+
+=item * Goto Definition
+
+=item * Find References
+
+=item * Call Signatures
+
+=item * Supports multiple workspace folders
+
+=item * Document and selection formatting via perltidy
+
+=item * Run on remote system via ssh
+
+=back
+
+=item * Debugger
+
+=over 4
+
+=item * Run, pause, step, next, return
+
+=item * Support for coro threads
+
+=item * Breakpoints 
+
+=item * Conditional breakpoints
+
+=item * Breakpoints can be set while program runs and for modules not yet loaded
+
+=item * Variable view, can switch to every stack frame or coro thread
+
+=item * Set variable
+
+=item * Watch variable
+
+=item * Tooltips with variable values
+
+=item * Evaluate perl code in debuggee, in context of every stack frame of coro thread
+
+=item * Automatically reload changed Perl modules while debugging
+
+=item * Debug multiple perl programs at once
+
+=item * Run on remote system via ssh
+
+=back
+
+=back
+
 =cut
 
 our $json = JSON -> new -> utf8(1) -> ascii(1) ;
@@ -219,7 +283,7 @@ sub call_method
         $perlmethod = (defined($id)?'_rpcreq_':'_rpcnot_') . $name ;
         }
     $self -> logger ("method=$perlmethod\n") if ($debug1) ;
-    die "Unknow perlmethod $perlmethod" if (!$self -> can ($perlmethod)) ;
+    die "Unknown perlmethod $perlmethod" if (!$self -> can ($perlmethod)) ;
 
 no strict ;
     return $self -> $perlmethod ($workspace, $req) ;
@@ -247,7 +311,7 @@ sub process_req
         my $is_dap = $type?1:0 ;
         $type      = defined ($id)?'request':'notification' if (!$type) ;
         $self -> logger ("handle_req id=$id\n") if ($debug1) ;
-        my $req = Perl::LanguageServer::Req  -> new ({ id => $id, is_dap => $is_dap, type => $type, params => $is_dap?$reqdata -> {arguments} || {}:$reqdata -> {params}}) ;
+        my $req = Perl::LanguageServer::Req  -> new ({ id => $id, is_dap => $is_dap, type => $type, params => $is_dap?$reqdata -> {arguments} || {}:$reqdata -> {params} || {}}) ;
         $running_reqs{$xid} = $req ;
 
         my $rsp ;
@@ -322,12 +386,15 @@ sub mainloop
         header:
         while (1)
             {
-            $self -> logger ("start aio read\n")  if ($debug2) ;
-            $cnt = $self -> _read (\$buffer, 8192, length ($buffer), undef, 1) ;
-            $self -> logger ("end aio read cnt=$cnt\n")  if ($debug2) ;
-            die "read_error reading headers ($!)" if ($cnt < 0) ;
-            return if ($cnt == 0) ;
-
+            $self -> logger ("start aio read, buffer len = " . length ($buffer) . "\n")  if ($debug2) ;
+            if ($loop)
+                {
+                $cnt = $self -> _read (\$buffer, 8192, length ($buffer), undef, 1) ;
+                $self -> logger ("end aio read cnt=$cnt, buffer len = " . length ($buffer) . "\n")  if ($debug2) ;
+                die "read_error reading headers ($!)" if ($cnt < 0) ;
+                return if ($cnt == 0) ;
+                }
+                
             while ($buffer =~ s/^(.*?)\R//)
                 {
                 $line = $1 ;    
@@ -634,6 +701,10 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Perl::LanguageServer
 
+Presentation on German Perl Workshop 2020:
+
+L<https://github.com/richterger/Perl-LanguageServer/blob/master/docs/Perl-LanguageServer%20und%20Debugger%20f%C3%BCr%20Visual%20Studio%20Code%20u.a.%20Editoren%20-%20Perl%20Workshop%202020.pdf>
+
 
 You can also look for information at:
 
@@ -642,31 +713,25 @@ You can also look for information at:
 =item * Github:
  L<https://github.com/richterger/Perl-LanguageServer>
 
-=item * RT: CPAN's request tracker (report bugs here)
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Perl-LanguageServer>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Perl-LanguageServer>
-
 =item * CPAN Ratings
 
 L<http://cpanratings.perl.org/d/Perl-LanguageServer>
 
-=item * Search CPAN
+=item * MetaCPAN
 
-L<http://search.cpan.org/dist/Perl-LanguageServer/>
+L<https://metacpan.org/release/Perl-LanguageServer>
 
 =back
 
+For reporting bugs please use GitHub issues.
+
 
 =head1 ACKNOWLEDGEMENTS
 
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2018-2020 grichter.
+Copyright 2018-2021 grichter.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
