@@ -116,7 +116,7 @@ sub send_event
 
 # ---------------------------------------------------------------------------
 
-sub lauch
+sub launch
     {
     my ($self, $workspace, $cmd) = @_ ;
 
@@ -129,13 +129,21 @@ sub lauch
         $ENV{$_} = $self -> env -> {$_} ;    
         }
 
+    my $cwd ;
+    if ($self -> cwd)
+        {
+        my $dir = $self -> cwd ;
+        $dir =~ s/'//g ;
+        $cwd = " chdir '$dir'; " ;
+        }
+
     my $inc = $workspace -> perlinc ;
     my @inc ;
     @inc = map { ('-I', $_)} @$inc if ($inc) ;
     
     $ENV{PLSDI_REMOTE} = '127.0.0.1:' . $self -> debug_adapter -> listen_port ;
     $ENV{PLSDI_OPTIONS} = $self -> reload_modules?'reload_modules':'' ;
-    $ENV{PERL5DB}      = 'BEGIN { $| = 1 ; require Perl::LanguageServer::DebuggerInterface }' ;
+    $ENV{PERL5DB}      = 'BEGIN { $| = 1 ; ' . $cwd . 'require Perl::LanguageServer::DebuggerInterface }' ;
     $ENV{PLSDI_SESSION}= $self -> session_id ;
     $pid = $self -> run_async ([$cmd, @inc, '-d', $fn, @{$self -> args}]) ;
     }
