@@ -80,6 +80,17 @@ sub _rpcnot_didChangeConfiguration
 
     $workspace -> show_local_vars ($workspace -> config -> {showLocalVars}) ;
     $workspace -> disable_cache   ($workspace -> config -> {disableCache}) ;
+    
+    if ($req -> params -> {settings}{perl}{cacheDir})
+        {
+        $workspace -> state_dir ($req -> params -> {settings}{perl}{cacheDir}) ;
+        }
+    else
+        {
+        $workspace -> clear_state_dir
+        }
+
+    $workspace -> mkpath ($workspace -> state_dir) ; # force build state dir
 
     async
         {
@@ -142,7 +153,7 @@ sub _rpcreq_symbol
         foreach my $symbol (@{$symbols->{$uri}})
             {
             next if ($symbol -> {name} !~ /$query/) ;
-            next if (!exists $symbol -> {defintion}) ;
+            next if (!exists $symbol -> {definition}) ;
             $line = $symbol -> {line} ;
             push @vars, { %$symbol, location => { uri => $uri, range => { start => { line => $line, character => 0 }, end => { line => $line, character => 0 }}} } ;
             last if (@vars > 200) ;
